# Enable detailed reporting
audit_report_detail="enabled"

# Report and log file paths
report_file="/var/log/lynis/lynis-report.dat"
log_file="/var/log/lynis/lynis.log"

# Enable full scans covering all security aspects
scan_profile_categories="malware, authentication, network, kernel, file_system, usb, storage, software_mgmt"

# Set verbose level to provide detailed client reports
verbose_level=2
