/var/log/chkrootkit/*.log {
    weekly
    rotate 4
    compress
    delaycompress
    missingok
    notifempty
    postrotate
        /etc/init.d/chkrootkit reload > /dev/null 2>&1 || true
    endscript
}
